@@ -22,7 +22,7 @@ def instance_data(i):
     vpc_only = ['sourceDestCheck', 'subnet_id', 'vpc_id']
 
     for key in verbatim:
-        v = i.__dict__[key]
+        v = getattr(i, key)
         if v == '' or v == None: # but not False
             continue
         data[key] = v
@@ -42,7 +42,11 @@ def instance_data(i):
     if tags:
         data['tags'] = tags
 
-    return name, data
+    if name != data['id']:
+        data['name'] = name
+        return name + '-' + data['id'], data
+    else:
+        return name, data
 
 def get_ec2_instances(econ):
     instances = NaturalOrderDict()
